/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * The settings for the Dialog actions when the Dialog is opened through `DialogService`
 * ([see example]({% slug api_dialog_dialogservice %}#toc-open)).
 */
export class DialogAction {
    /**
     * The text of the action button.
     */
    text;
    /**
     * Determines the theme color of the action button. The theme color will be applied as a background and border color while also amending the text color accordingly.
     */
    themeColor;
    /**
     * Specifies the background and border styles of the action button.
     */
    fillMode;
    /**
     * Sets the CSS classes that will be rendered on the action button.
     * Supports the union type of values that [ngClass](link:site.data.urls.angular['ngclassapi']) accepts.
     */
    cssClass;
    /**
     * Specifies the [SVG icon](slug:svgicon_list) to be rendered within the action button.
     */
    svgIcon;
    /**
     * Specifies the name of the [font icon](slug:icon_list) to be rendered within the action button.
     */
    icon;
    /**
     * @hidden
     */
    disabled;
}
